@@ -41,9 +41,8 @@ class BaseCommand(asyncio.Future, StatusMixIn):
         actor but if we are commanding another actor ``consumer_id`` will
         be the destination actor.
     parent : .BaseCommand
-        Another `.BaseCommand` object that is issuing this subcommand. If they
-        are not specified, sets ``commander_id`` and ``consumer_id``
-        appropriately.
+        Another `.BaseCommand` object that is issuing this subcommand.
+        Messages emitted by the command will use the parent ``command_id``.
     status_callback : function
         A function to call when the status changes.
     call_now : bool
@@ -66,16 +65,6 @@ class BaseCommand(asyncio.Future, StatusMixIn):
 
         self.parent = parent
 
-        if self.parent:
-            if not isinstance(self.parent, BaseCommand):
-                raise clu.CluError('invalid parent type.')
-            if self.parent.command_id != 0 and self.command_id == self.parent.command_id:
-                raise clu.CluError('subcommand cannot have the '
-                                   'same command_id as the parent.')
-
-            self.commander_id = self.commander_id or self.parent.commander_id
-            self.consumer_id = self.consumer_id or self.parent.consumer_id
-
         self.default_keyword = default_keyword
         self.loop = loop or asyncio.get_event_loop()
 
@@ -106,12 +95,14 @@ class BaseCommand(asyncio.Future, StatusMixIn):
             integer associated with the maskbit. If ``value`` is a string,
             loops over the bits in `CommandStatus` and assigns the one whose
             name matches.
+        silent : bool
+            Update the status but do not output it with a message to the users.
 
         """
 
         self.set_status(status)
 
-    def set_status(self, status, message=None, **kwargs):
+    def set_status(self, status, message=None, silent=False, **kwargs):
         """Same as `.status` but allows to specify a message to the users."""
 
         if self.status.is_done:
@@ -137,7 +128,7 @@ class BaseCommand(asyncio.Future, StatusMixIn):
 
             status_code = status.code
 
-            if self.actor:
+            if self.actor and not silent:
                 self.write(status_code, message, **kwargs)
 
             self._status = status
@@ -211,8 +202,11 @@ class BaseCommand(asyncio.Future, StatusMixIn):
             raise clu.CommandError('An actor has not been defined for '
                                    'this command. Cannot write to users.')
 
-        result = self.actor.write(message_code, message=message, command=self,
-                                  broadcast=broadcast, **kwargs)
+        command = self if not self.parent else self.parent
+
+        result = self.actor.write(message_code, message=message,
+                                  command=command, broadcast=broadcast,
+                                  **kwargs)
 
         if asyncio.iscoroutine(result):
             self.loop.create_task(result)
